@@ -1,19 +1,17 @@
-use crate::actions::{
-    german::{
-        machine::{StateMachine, Transition},
-        words::{Replace, Replacement, WordCasing},
-    },
-    Action,
-};
-use cached::proc_macro::cached;
+use std::sync::LazyLock;
+
 use cached::SizedCache;
-use decompound::{decompound, DecompositionOptions};
+use cached::proc_macro::cached;
+use decompound::{DecompositionOptions, decompound};
 use itertools::Itertools;
 use itertools::MinMaxResult::{MinMax, NoElements, OneElement};
 use log::{debug, trace};
-use once_cell::sync::Lazy;
 use unicode_titlecase::StrTitleCase;
 
+use crate::actions::Action;
+use crate::actions::german::machine::{StateMachine, Transition};
+use crate::actions::german::words::{Replace, Replacement, WordCasing};
+
 /// German language action, responsible for Umlauts and Eszett.
 ///
 /// This action is responsible for applying the following rules, [**where
@@ -32,38 +30,32 @@ use unicode_titlecase::StrTitleCase;
 /// errors in processing could be the result of a faulty word list *or* faulty
 /// algorithms.
 ///
-/// # Example: A simple greeting, with Umlaut and Eszett
+/// # Examples
+///
+/// Provided here as a single doctest due to [performance
+/// issues](https://github.com/rust-lang/rust/issues/75341).
 ///
 /// ```
 /// use srgn::actions::{Action, German};
 ///
 /// let action = German::default();
+///
+/// // A simple greeting, with Umlaut and Eszett
 /// let result = action.act("Gruess Gott!");
 /// assert_eq!(result, "Grüß Gott!");
-/// ```
 ///
-/// # Example: A compound word
-///
-/// Note that this compound word is *not* part of the word list (that would be an
-/// *elaborate* word list!), but is still handled, as its constituents are.
-///
-/// ```
-/// use srgn::actions::{Action, German};
-///
-/// let action = German::default();
+/// // A compound word
+/// //
+/// // Note that this compound word is *not* part of the word list (that would be an
+/// // *elaborate* word list!), but is still handled, as its constituents are.
 /// let result = action.act("Du Suesswassertagtraeumer!");
 /// assert_eq!(result, "Du Süßwassertagträumer!");
-/// ```
-///
-/// # Example: Words *validly* containing alternative Umlaut spelling
-///
-/// These spellings are *not* replaced, as they are valid words in their own right.
-/// Naive implementations/translations (e.g.
-/// [`tr`](https://en.wikipedia.org/wiki/Tr_(Unix))) would not handle this correctly.
-///
-/// ```
-/// use srgn::actions::{Action, German};
 ///
+/// // Words *validly* containing alternative Umlaut spelling
+/// //
+/// // These spellings are *not* replaced, as they are valid words in their own right.
+/// // Naive implementations/translations (e.g.
+/// // [`tr`](https://en.wikipedia.org/wiki/Tr_(Unix))) would not handle this correctly.
 /// for word in &[
 ///     // "ae"
 ///     "Aerodynamik",   // should not be "Ärodynamik"
@@ -84,15 +76,15 @@ use unicode_titlecase::StrTitleCase;
 /// }
 /// ```
 ///
-/// Note that `ss`/`ß` is not mentioned, as it is handled
-/// [elsewhere][`German::new`], dealing with the topic of words with valid
-/// alternative *and* special character spellings.
+/// Note that `ss`/`ß` is not mentioned, as it is handled [elsewhere][`German::new`],
+/// dealing with the topic of words with valid alternative *and* special character
+/// spellings.
 ///
 /// # Example: Upper- and mixed case
 ///
-/// This action can handle any case, but assumes **nouns are never lower case** (a pretty
-/// mild assumption). The **first letter governs the case** of the entity (Umlaut,
-/// Eszett or entire word) in question:
+/// This action can handle any case, but assumes **nouns are never lower case** (a
+/// pretty mild assumption). The **first letter governs the case** of the entity
+/// (Umlaut, Eszett or entire word) in question:
 ///
 /// | Input | Example Umlaut/Eszett | Example word | Detected case |
 /// | ----- | --------------------- | ------------ | ------------- |
@@ -107,47 +99,25 @@ use unicode_titlecase::StrTitleCase;
 /// If whatever case was detected is not considered a valid word, the replacement is not
 /// made. Example flows follow.
 ///
-/// ## Subexample: mixed case, invalid word
-///
-/// The flow looks like:
-///
-/// `aEpFeL` → lowercase Umlaut → `äpFeL` → lowercase word → squash → `äpfel` → ❌ →
-/// output is `aEpFeL`
-///
-///
 /// ```
 /// use srgn::actions::{Action, German};
 ///
 /// let action = German::default();
+///
+///
+/// // `aEpFeL` → lowercase Umlaut → `äpFeL` → lowercase word → squash → `äpfel` → ❌ →
+/// // output is `aEpFeL`
 /// let result = action.act("aEpFeL");
-///
-/// // Error: MiXeD CaSe noun without leading capital letter
+/// // Error: MiXeD CaSe noun without leading capital letter.
 /// assert_eq!(result, "aEpFeL");
-/// ```
 ///
-/// ## Subexample: mixed case, valid word
-///
-/// The flow looks like:
-///
-/// `AePfEl` → uppercase Umlaut → `ÄPfEl` → uppercase word → squash → `Äpfel` → ✅ →
-/// output is `Äpfel`
-///
-/// ```
-/// use srgn::actions::{Action, German};
-///
-/// let action = German::default();
+/// // `AePfEl` → uppercase Umlaut → `ÄPfEl` → uppercase word → squash → `Äpfel` → ✅ →
+/// // output is `Äpfel`
 /// let result: String = action.act("AePfEl");
-///
 /// // OK: MiXeD CaSe words nouns are okay, *if* starting with a capital letter
 /// assert_eq!(result, "ÄPfEl");
-/// ```
 ///
-/// ## Subexample: other cases
-///
-/// ```
-/// use srgn::actions::{Action, German};
-///
-/// let action = German::default();
+/// // Other cases
 /// let f = |word: &str| -> String {action.act(word)};
 ///
 /// // OK: The normal case, adjective lowercase
@@ -173,17 +143,8 @@ use unicode_titlecase::StrTitleCase;
 ///
 /// // OK: MiXeD CaSe verb: inserted special character is lowercase
 /// assert_eq!(f("FuElLEn"), "FülLEn");
-/// ```
 ///
-/// ### Capital Eszett (ẞ)
-///
-/// Note the spelling of `SCHLIEẞEN` containing `ẞ`, the [uppercase version of
-/// `ß`](https://www.wikidata.org/wiki/Q9693), part of [official spelling since
-/// 2017](https://web.archive.org/web/20230206102049/https://www.rechtschreibrat.com/DOX/rfdr_PM_2017-06-29_Aktualisierung_Regelwerk.pdf).
-/// It's the result of uppercasing `ß` of `schließen`. This does **not** follow Rust's
-/// usual behavior, which is why it is specially mentioned here:
-///
-/// ```
+/// // Eszett behavior
 /// let lc = "ß";
 /// let uc = "ẞ";
 ///
@@ -199,10 +160,17 @@ use unicode_titlecase::StrTitleCase;
 /// assert_eq!(lc.to_lowercase().to_string(), lc);
 /// ```
 ///
-/// The `SS` of `SCHLIESSEN` is detected as an uppercase Eszett, which is specifically
-/// inserted. You might want to run additional processing if this is undesired.
+/// ### Capital Eszett (ẞ)
 ///
-/// # Example: Other bytes
+/// Note the spelling of `SCHLIEẞEN` containing `ẞ`, the [uppercase version of
+/// `ß`](https://www.wikidata.org/wiki/Q9693), part of [official spelling since
+/// 2017](https://web.archive.org/web/20230206102049/https://www.rechtschreibrat.com/DOX/rfdr_PM_2017-06-29_Aktualisierung_Regelwerk.pdf).
+/// It's the result of uppercasing `ß` of `schließen`. This does **not** follow Rust's
+/// usual behavior, which is why it is specially mentioned here. The `SS` of
+/// `SCHLIESSEN` is detected as an uppercase Eszett, which is specifically inserted. You
+/// might want to run additional processing if this is undesired.
+///
+/// # Other bytes
 ///
 /// This action handles the German alphabet *only*, and will leave other input bytes
 /// untouched. You get to keep your trailing newlines, emojis (also multi-[`char`]
@@ -211,14 +179,6 @@ use unicode_titlecase::StrTitleCase;
 /// Of course, the input has to be valid UTF-8, as is ensured by its signature
 /// ([`str`]).
 ///
-/// ```
-/// use srgn::actions::{Action, German};
-///
-/// let action = German::default();
-/// let result = action.act("\0Schoener    你好 Satz... 👋🏻\r\n\n");
-/// assert_eq!(result, "\0Schöner    你好 Satz... 👋🏻\r\n\n");
-/// ```
-///
 /// # Performance
 ///
 /// This action is implemented as a [finite state
@@ -260,12 +220,12 @@ impl German {
     /// # Arguments
     ///
     /// * `prefer_original`: For a tied situation, where an original word and some
-    /// replacement are *both* legal, controls which one is returned. See
-    /// [below](#example-words-valid-both-in-original-and-replaced-form) for when this
-    /// is relevant.
+    ///   replacement are *both* legal, controls which one is returned. See
+    ///   [below](#example-words-valid-both-in-original-and-replaced-form) for when this
+    ///   is relevant.
     /// * `naive`: If `true`, perform any possible replacement, regardless of legality
-    /// of the resulting word. Useful for names, which are otherwise not modifiable as
-    /// they do not occur in dictionaries. See [example](#example-naive-mode).
+    ///   of the resulting word. Useful for names, which are otherwise not modifiable as
+    ///   they do not occur in dictionaries. See [example](#example-naive-mode).
     ///
     /// ## Example: Words valid both in original and replaced form
     ///
@@ -310,15 +270,8 @@ impl German {
     ///    let result = action.act(original);
     ///    assert_eq!(result, original.to_string());
     /// }
-    /// ```
-    ///
-    /// ## Example: naive mode
-    ///
-    /// Naive mode is essentially forcing a maximum number of replacements.
-    ///
-    /// ```
-    /// use srgn::actions::{Action, German};
     ///
+    /// // Naive mode is essentially forcing a maximum number of replacements.
     /// for (original, output) in &[
     ///     ("Frau Schroekedaek", "Frau Schrökedäk"), // Names are not in the word list
     ///     ("Abenteuer", "Abenteür"), // Illegal, but possible now
@@ -340,9 +293,8 @@ impl German {
     ///    assert_eq!(result, original.to_string());
     /// }
     /// ```
-    ///
     #[must_use]
-    pub fn new(prefer_original: bool, naive: bool) -> Self {
+    pub const fn new(prefer_original: bool, naive: bool) -> Self {
         Self {
             prefer_original,
             naive,
@@ -493,12 +445,9 @@ fn find_valid_replacement(
     // iteration. Then, `Busse` will turn out to be valid already and will be returned .
     // Skipping it means `Buße` is tried, which is *also* valid and returned, foregoing
     // `Busse`.
-    debug_assert!(replacement_combinations
-        .first()
-        .map_or(true, std::vec::Vec::is_empty));
+    debug_assert!(replacement_combinations.first().is_none_or(Vec::is_empty));
 
-    #[allow(clippy::bool_to_int_with_if)] // Readability is much better.
-    let n_skip = if prefer_original { 0 } else { 1 };
+    let n_skip = (!prefer_original).into();
 
     for replacements in replacement_combinations.into_iter().skip(n_skip) {
         let mut candidate = word.to_owned();
@@ -520,7 +469,7 @@ fn find_valid_replacement(
     None
 }
 
-static SET: Lazy<fst::Set<&[u8]>> = Lazy::new(|| {
+static SET: LazyLock<fst::Set<&[u8]>> = LazyLock::new(|| {
     let bytes: &'static [u8] = include_bytes!(concat!(env!("OUT_DIR"), "/de.fst")); // Generated in `build.rs`.
     trace!("Loading FST.");
     let set = fst::Set::new(bytes).expect("Failed to load FST; FST bytes malformed at build time?");
@@ -538,8 +487,8 @@ fn contained_in_global_word_list(word: &str) -> bool {
 
 // https://github.com/jaemk/cached/issues/135#issuecomment-1315911572
 #[cached(
-    type = "SizedCache<String, bool>",
-    create = "{ SizedCache::with_size(1024) }",
+    ty = "SizedCache<String, bool>",
+    create = "{ SizedCache::with_size(256) }",
     convert = r#"{ String::from(word) }"#
 )]
 fn is_valid(word: &str, predicate: &impl Fn(&str) -> bool) -> bool {
@@ -606,9 +555,10 @@ fn is_valid(word: &str, predicate: &impl Fn(&str) -> bool) -> bool {
 
 #[cfg(test)]
 mod tests {
-    use super::*;
     use rstest::rstest;
 
+    use super::*;
+
     #[test]
     fn test_word_list_is_not_filtered() {
         let mut stream = SET.stream();
@@ -724,6 +674,12 @@ mod tests {
         "Oel ist ein wichtiger Bestandteil von Oel.",
         "Öl ist ein wichtiger Bestandteil von Öl."
     )]
+    //
+    // Edge cases
+    #[case(
+        "\0Schoener    你好 Satz... 👋🏻\r\n\n",
+        "\0Schöner    你好 Satz... 👋🏻\r\n\n"
+    )]
     fn test_substitution(#[case] input: &str, #[case] expected: &str) {
         let action = German::default();
         let result = action.act(input);
