@@ -57,7 +57,9 @@ impl TryFrom<&str> for WordCasing {
             (_, true, false) => Ok(Self::AllLowercase),
             (_, false, true) => Ok(Self::AllUppercase),
             (_, true, true) => Ok(Self::Mixed),
-            (_, false, false) => unreachable!("Impossible case: any non-empty string has either lower- or uppercase or returned an `Err` early."),
+            (_, false, false) => unreachable!(
+                "Impossible case: any non-empty string has either lower- or uppercase or returned an `Err` early."
+            ),
         }
     }
 }
@@ -253,8 +255,8 @@ mod tests {
         assert_eq!(WordCasing::try_from(input), expected);
     }
 }
+
 #[cfg(test)]
-#[allow(clippy::ignored_unit_patterns)] // in `proptest` macro, cannot be avoided
 mod properties {
     use proptest::prelude::*;
 
