@@ -745,6 +745,30 @@ Heizoelrueckstossabdaempfung.
         ],
         Some(Path::new("tests/langs/go/vendor-dir-test/")), // Contains vendor dir
     )]
+    #[case(
+        // tree-sitter regular expressions do not support `fancy_regex` features such as
+        // lookaheads. This is validated during CLI arg parsing time, instead of failing
+        // much later at runtime in the tree-sitter library, at which we point we lose
+        // rich error messages.
+        "tree-sitter-invalid-regex-validated-at-parse-time",
+        None,
+        &[
+            "--rust",
+            "struct~(?<=Foo)Bar",
+        ],
+        None,
+    )]
+    #[case(
+        // Some grammar elements/node types do not support "namedness" - they are
+        // anonymous. This should be caught and rejected at parse time.
+        "unsupported-named-entities-validated-at-parse-time",
+        None,
+        &[
+            "--rust",
+            "comments~InherentlyHaveNoNames",
+        ],
+        None,
+    )]
     fn test_cli_failure_modes(
         #[case] snapshot_name: String,
         #[case] stdin: Option<&str>,
@@ -817,7 +841,7 @@ Heizoelrueckstossabdaempfung.
 
         let input = b"invalid utf8 \xFF";
 
-        #[allow(invalid_from_utf8)] // Attribute didn't work on `assert` macro?
+        #[expect(invalid_from_utf8)] // Attribute didn't work on `assert` macro?
         let check = std::str::from_utf8(input);
         assert!(check.is_err(), "Input is valid UTF8, test is broken");
 
@@ -852,12 +876,14 @@ Heizoelrueckstossabdaempfung.
                         .expect("(our) directories under test always have parents")
                         .to_owned();
 
-                    assert!(check_directories_equality(
-                        // Impossible: a directory always compares unequal to a subdirectory
-                        // of itself.
-                        parent, path
-                    )
-                    .is_err());
+                    assert!(
+                        check_directories_equality(
+                            // Impossible: a directory always compares unequal to a subdirectory
+                            // of itself.
+                            parent, path
+                        )
+                        .is_err()
+                    );
                 }
             }
         }
