@@ -15,13 +15,14 @@ mod tests {
     use core::{fmt, panic};
     use std::cell::RefCell;
     use std::collections::{HashMap, VecDeque};
+    use std::error::Error;
     use std::io::Write;
     use std::mem::ManuallyDrop;
     use std::rc::Rc;
 
     use assert_cmd::Command;
     use comrak::nodes::{NodeCodeBlock, NodeValue};
-    use comrak::{parse_document, Arena, ComrakOptions};
+    use comrak::{Arena, ComrakOptions, parse_document};
     use fancy_regex::Regex;
     use itertools::Itertools;
     use nom::branch::alt;
@@ -32,7 +33,7 @@ mod tests {
     };
     use nom::combinator::{cut, eof, map, opt, recognize};
     use nom::error::ParseError;
-    use nom::multi::{many0, many1, many_till, separated_list1};
+    use nom::multi::{many_till, many0, many1, separated_list1};
     use nom::sequence::{delimited, preceded, tuple};
     use nom::{Finish, IResult};
     use pretty_assertions::assert_eq;
@@ -40,7 +41,8 @@ mod tests {
     use unescape::unescape;
 
     const PROGRAM_NAME: &str = env!("CARGO_PKG_NAME");
-    const DOCUMENT: &str = include_str!("../README.md");
+    const PATH: &str = concat!(env!("CARGO_MANIFEST_DIR"), "/", "README.md");
+    const FIX_ENV_VAR: &str = "FIX_README";
 
     /// A flag, either short or long.
     ///
@@ -77,7 +79,7 @@ mod tests {
     /// Has a value, e.g. `--option value` or `-o value`.
     #[derive(Debug, Clone, PartialEq, Eq)]
     enum Opt {
-        #[allow(dead_code)] // Not used yet
+        #[expect(dead_code)] // Not used yet
         Short(char, String),
         Long(String, String),
     }
@@ -315,7 +317,7 @@ mod tests {
             // Set the *second*, if any, command's standard input.
             match programs.front_mut() {
                 Some(Program::Echo(_) | Program::Cat(_)) => {
-                    return Err("Stdin-generating program should not be in the middle of a pipe")
+                    return Err("Stdin-generating program should not be in the middle of a pipe");
                 }
                 Some(Program::Self_(inv)) => {
                     inv.stdin = stdin;
@@ -331,7 +333,7 @@ mod tests {
             let mut first = first;
             match programs.back_mut() {
                 Some(Program::Echo(_) | Program::Cat(_)) => {
-                    return Err("Stdin-generating program should not be at the end of a pipe")
+                    return Err("Stdin-generating program should not be at the end of a pipe");
                 }
                 Some(Program::Self_(inv)) => {
                     inv.stdout = if should_fail {
@@ -358,7 +360,7 @@ mod tests {
                     match &mut first {
                         // There is no 'last program': we have a stand-alone one.
                         Program::Echo(_) | Program::Cat(_) => {
-                            return Err("Illegal standalone program")
+                            return Err("Illegal standalone program");
                         }
                         Program::Self_(inv) => {
                             inv.stdout = Some(
@@ -466,7 +468,7 @@ mod tests {
     }
 
     /// Parses a single, whole program invocation.
-    #[allow(clippy::too_many_lines)] // :( many hard-coded values
+    #[expect(clippy::too_many_lines)] // :( many hard-coded values
     fn parse_program(input: &str) -> IResult<&str, Program> {
         // Interior mutability is fine, as the different closures aliasing this run
         // sequentially, never at once (is using this and `map` of `nom` an
@@ -653,8 +655,7 @@ mod tests {
     #[derive(Debug, Clone, PartialEq, Eq)]
     enum OS {
         Linux,
-        #[allow(clippy::enum_variant_names)]
-        MacOS,
+        Darwin,
         Windows,
     }
 
@@ -665,7 +666,7 @@ mod tests {
         fn try_from(value: String) -> Result<Self, Self::Error> {
             match value.as_str() {
                 "linux" => Ok(Self::Linux),
-                "macos" => Ok(Self::MacOS),
+                "macos" => Ok(Self::Darwin),
                 "windows" => Ok(Self::Windows),
                 // Just a double check to ensure parsing of options went right.
                 _ => Err("unknown OS"),
@@ -738,10 +739,10 @@ mod tests {
 
     type Snippets = HashMap<String, Snippet>;
 
-    fn get_readme_snippets() -> Snippets {
+    fn get_readme_snippets(doc: &str) -> Snippets {
         let mut snippets = HashMap::new();
 
-        map_on_markdown_codeblocks(DOCUMENT, |ncb| {
+        map_on_markdown_codeblocks(doc, |ncb| {
             if let Some((_language, options)) = ncb.info.split_once(' ') {
                 let mut snippet = Snippet::default();
                 let options: BlockOptions = options.into();
@@ -774,10 +775,10 @@ mod tests {
         snippets
     }
 
-    fn get_readme_program_pipes(snippets: &Snippets) -> Vec<PipedPrograms> {
+    fn get_readme_program_pipes(doc: &str, snippets: &Snippets) -> Vec<PipedPrograms> {
         let mut pipes = Vec::new();
 
-        map_on_markdown_codeblocks(DOCUMENT, |ncb| {
+        map_on_markdown_codeblocks(doc, |ncb| {
             let (language, options): (&str, Option<BlockOptions>) = ncb
                 .info
                 .split_once(' ')
@@ -826,11 +827,12 @@ mod tests {
     }
 
     #[test]
-    fn test_readme_code_blocks() {
-        let _helper = TestHinter;
+    fn test_readme_code_blocks() -> Result<(), Box<dyn Error>> {
+        let _hinter = TestHinter;
 
-        let snippets = get_readme_snippets();
-        let pipes = get_readme_program_pipes(&snippets);
+        let contents = std::fs::read_to_string(PATH)?;
+        let snippets = get_readme_snippets(&contents);
+        let pipes = get_readme_program_pipes(&contents, &snippets);
 
         for pipe in pipes {
             let mut previous_stdin = None;
@@ -875,37 +877,48 @@ mod tests {
                     }
 
                     if observed_stdout != expected_stdout {
-                        // Write to files for easier inspection
-                        let (mut obs_f, mut exp_f) = (
-                            ManuallyDrop::new(NamedTempFile::new().unwrap()),
-                            ManuallyDrop::new(NamedTempFile::new().unwrap()),
-                        );
+                        if std::env::var(FIX_ENV_VAR).as_deref() == Ok("1") {
+                            let old_readme = std::fs::read_to_string(PATH)?;
+                            // We'd REALLY want the exact byte ranges here for exact
+                            // precision, but those aren't easily available. This
+                            // naive replacement will fail in various scenarios.
+                            let new_readme = old_readme.replace(&expected_stdout, &observed_stdout);
 
-                        obs_f.write_all(observed_stdout.as_bytes()).unwrap();
-                        exp_f.write_all(expected_stdout.as_bytes()).unwrap();
+                            assert!(old_readme != new_readme, "No changes made to {PATH}, bug.");
 
-                        // Now panic as usual, for the usual output
-                        assert_eq!(
-                            // Get some more readable output diff compared to
-                            // `assert::Command`'s `stdout()` function, for which diffing
-                            // whitespace is very hard.
-                            expected_stdout,
-                            observed_stdout,
-                            "Output differs; for inspection see observed stdout at '{}', expected stdout at '{}'",
-                            obs_f.path().display(),
-                            exp_f.path().display()
-                        );
+                            std::fs::write(PATH, new_readme)?;
+                        } else {
+                            // Write to files for easier inspection
+                            let (mut obs_f, mut exp_f) = (
+                                ManuallyDrop::new(NamedTempFile::new().unwrap()),
+                                ManuallyDrop::new(NamedTempFile::new().unwrap()),
+                            );
 
-                        // Temporary files remain, they're not dropped.
+                            obs_f.write_all(observed_stdout.as_bytes()).unwrap();
+                            exp_f.write_all(expected_stdout.as_bytes()).unwrap();
 
-                        unreachable!();
+                            // Now panic as usual, for the usual output
+                            assert_eq!(
+                                // Get some more readable output diff compared to
+                                // `assert::Command`'s `stdout()` function, for which diffing
+                                // whitespace is very hard.
+                                expected_stdout,
+                                observed_stdout,
+                                "Output differs; for inspection see observed stdout at '{}', expected stdout at '{}'",
+                                obs_f.path().display(),
+                                exp_f.path().display()
+                            );
+
+                            // Temporary files remain, they're not dropped.
+                        }
                     }
                 }
-
                 // Pipe stdout to stdin of next run...
                 previous_stdin = Some(observed_stdout);
             }
         }
+
+        Ok(())
     }
 
     fn fix_windows_output(mut input: String) -> String {
@@ -966,11 +979,12 @@ mod tests {
     impl Drop for TestHinter {
         fn drop(&mut self) {
             if std::thread::panicking() {
-                println!("\n==============================================");
-                println!("💡 README test failed!");
-                println!("Did you update the `srgn --help` output?");
-                println!("If no, run `./scripts/update-readme.py README.md` and try again.");
-                println!("==============================================\n");
+                println!(
+                    r"
+💡 README test failed!
+Run with `{FIX_ENV_VAR}=1` env var to fix the README automatically (BEST EFFORT!).
+"
+                );
             }
         }
     }
